/*
  fcfs_readobj.c
  -------------

  reads an object from FCFS and writes it to stdout
  
  $Id: fcfs_readobj.c,v 1.2 2003/09/22 09:03:04 stewart Exp $
  
  (C)2003 Stewart Smith
  Distributed under the GPL
*/

#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <time.h>


#include "testkit/block_dev.h"
#include "testkit/types.h"
#include "testkit/bitops.h"
#include "disk.h"

#include "super_block.h"
#include "onode.h"
#include "onode_index.h"
#include "space_bitmap.h"
#include "fcfs_vfs.h"

#define EXPERIMENTAL

int main(int argc, char* argv[])
{
  struct fcfs_disk* disk;
  struct fcfs_onode_index* index;
  int i;
  struct fcfs_disk_block *onode_block;
  struct fcfs_onode1 *onode;
  struct fcfs_block_run onode_br;
  int forknr;
  char *data; int j;
  int infile;
  u64 rlen, len;
  struct fcfs_block *b;
  
  data = (char*)malloc(50000);

  if(argc<3)
    {
      fprintf(stderr,"fcfs_readobj\n");
      fprintf(stderr,"-----------\n");
      fprintf(stderr,"$Id: fcfs_readobj.c,v 1.2 2003/09/22 09:03:04 stewart Exp $\n");
      fprintf(stderr,"Usage:\n");
      fprintf(stderr,"\t%s volume objid\n\n",argv[0]);
      exit(1);
    }

  disk = fcfs_mount(argv[1]);

  index = onode_index_read(disk);

  onode_block = onode_index_lookup(index, &onode_br,atoi(argv[2]));
  onode = (struct fcfs_onode1*)onode_block->data;

  for(rlen = 0; (len=onode1_fork_read(disk,onode,1,rlen,1000,data)) && len>0;rlen+=len)
    write(1,data,len);

  disk_freeblock(onode_block);
  fcfs_umount(disk);

  return 0;
}
