/* mount_testkit.c
   ---------------
   $Id: mount_testkit.c,v 1.2 2003/09/22 09:03:26 stewart Exp $

   This is the code to mount a fcfs volume using the testkit stuff.
   a bit icky, but it should work.

   (C)2003 Stewart Smith
   Distributed under the GNU Public License
 */

#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <time.h>


#include "testkit/block_dev.h"
#include "testkit/types.h"
#include "testkit/bitops.h"
#include "disk.h"

#include "super_block.h"
#include "onode.h"
#include "onode_index.h"
#include "space_bitmap.h"


struct fcfs_disk *fcfs_mount(char *name)
{
  struct block_device bdev,*bdevproper;
  struct fcfs_disk *disk,*diskproper;
  struct fcfs_disk_block *block;
  u32 bsize;     // block size (bytes)
  u64 blocksnr;  // number of blocks

  bdevproper = (struct block_device*)malloc(sizeof(struct block_device));
  if(bdevproper==NULL)
    {
      fprintf(stderr,"No memory for bdevproper\n");
      abort();
    }

  block_dev_init();
  block_dev_new(&bdev,name,4096,1);
  disk = disk_new(&bdev);

  block = disk_getblock(disk,0);
  disk->sb = (struct fcfs_sb*)block->data;

  bsize = disk->sb->bsize;
  blocksnr = disk->sb->blocksnr;

  /* clean up after initial detection */
  disk_freeblock(block);
  disk_free(disk);

  /* Let's use our knowledge to make a proper disk */
  block_dev_new(bdevproper,name,bsize,blocksnr);
  diskproper = disk_new(bdevproper);
  
  /* Put proper superblock into disk */
  block = disk_getblock(diskproper,0);
  disk->sb_block = block;
  disk->sb = (struct fcfs_sb*)block->data;

  fcfs_sb_mark_dirty(disk);

  return disk;
}

int fcfs_umount(struct fcfs_disk *disk)
{
  fcfs_sb_mark_clean(disk);
  disk_freeblock(disk->sb_block);
  disk_free(disk);
  return 0;
}
