/*
  bitops.h
  --------
  $Id: bitops.h,v 1.3 2003/07/06 12:28:03 stewart Exp $

  functions similar to those present in include/asm/bitops.h
  There is no *real* guarantee of being atomic, except for the
  "we're not doing threads so go away" thing.

  (C)2003 Stewart Smith
  Distributed under the GNU Public License.

  Some data structures have been constructed out of those
  present in the Linux Kernel (v2.5.69). They are copyright
  of their respective owners.

  The API here is very much based on Linux kernel stuff.
  Except that we don't do inline ASM to do this 'atomic' stuff.
  bah - we live on the edge baby!
 */

#ifndef __BITOPS_H__
#define __BITOPS_H__

#define ADDR (* (volatile long *) addr)

static inline void set_bit(int nr, volatile void * addr)
{
  ADDR = ADDR | 1UL << nr;
}

static inline int test_and_set_bit(int nr, volatile void * addr)
{
  int oldbit;
  oldbit = ADDR & 1UL << nr;
  set_bit(nr,addr);
  return oldbit;
}

static inline void clear_bit(int nr,volatile void * addr)
{
  ADDR = ADDR & ~(1UL << nr);
}

static inline int test_and_clear_bit(int nr,volatile void * addr)
{
  int oldbit;
  oldbit = ADDR & (1UL << nr);
  clear_bit(nr,addr);
  return oldbit;
}

static inline int test_bit(int nr,volatile void * addr)
{
  return ADDR & (1UL << nr);
}

#endif
